==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/db.mysql/src/org/netbeans/modules/db/mysql/installations/WindowsStandaloneInstallation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.db.mysql.installations;

import org.netbeans.modules.db.mysql.impl.Installation;
import org.netbeans.modules.db.mysql.util.Utils;
import org.openide.util.Utilities;

/**
 * Standalone version on Windows, not installed as a server
 *
 * @author David Van Couvering
 */
public class WindowsStandaloneInstallation implements Installation {
    static final String DEFAULT_BASE_PATH = "C:/Program Files/MySQL/";  //NOI18N
    static final String FOLDER_NAME_PREFIX = "MySQL Server ";           //NOI18N
    
    private final String basePath;

    protected WindowsStandaloneInstallation(String folderName) {
        this.basePath = DEFAULT_BASE_PATH + folderName;
    }
    
    public String[] getStartCommand() {
        return new String[] { basePath + "/bin/mysqld.exe", "--console"}; // NOI18N
    }

    public String[] getStopCommand() {
        return new String[] { basePath + "/bin/mysqladmin.exe", "-u root shutdown"}; // NOI18N
    }
    
    public boolean isInstalled() {
        return Utilities.isWindows() && 
                Utils.isValidExecutable(getStartCommand()[0]);
    }

    public boolean isStackInstall() {
        return false;
    }

    public String[] getAdminCommand() {
        return new String[] { "", ""};
    }

    public String getDefaultPort() {
        return "3306"; // NOI18N
    }

    public Installation getInstallation(String command, Command cmdType) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String toString() {
        return "Windows Installation - " + basePath;                    //NOI18N
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/db.mysql/src/org/netbeans/modules/db/mysql/installations/WindowsStandaloneInstallation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.db.mysql.installations;

import java.io.File;
import org.netbeans.modules.db.mysql.impl.Installation;
import org.netbeans.modules.db.mysql.util.Utils;
import org.openide.filesystems.FileUtil;
import org.openide.util.Utilities;

/**
 * Standalone version on Windows, not installed as a server
 *
 * @author David Van Couvering
 */
public class WindowsStandaloneInstallation implements Installation {
    static final File DEFAULT_BASE_PATH = FileUtil.normalizeFile(new File("C:/Program Files/MySQL/"));  //NOI18N
    static final String FOLDER_NAME_PREFIX = "MySQL Server ";           //NOI18N
    
    private final File basePath;

    protected WindowsStandaloneInstallation(String folderName) {
        this.basePath = new File(DEFAULT_BASE_PATH, folderName);
    }
    
    public String[] getStartCommand() {
        return new String[] { new File(basePath, "/bin/mysqld.exe").getAbsolutePath(), "--console"}; // NOI18N
    }

    public String[] getStopCommand() {
        return new String[] { new File(basePath, "/bin/mysqladmin.exe").getAbsolutePath(), "-u root shutdown"}; // NOI18N
    }
    
    public boolean isInstalled() {
        return Utilities.isWindows() && 
                Utils.isValidExecutable(getStartCommand()[0]);
    }

    public boolean isStackInstall() {
        return false;
    }

    public String[] getAdminCommand() {
        return new String[] { "", ""};
    }

    public String getDefaultPort() {
        return "3306"; // NOI18N
    }

    public Installation getInstallation(String command, Command cmdType) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String toString() {
        return "Windows Installation - " + basePath;                    //NOI18N
    }
}
